/** \file black.h
   Represents the black hostile balls in the game.
*/
/*
   Copyright (C) 2000  Mathias Broxvall

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef BLACK_H
#define BLACK_H

#include "ball.h"

class Black : public Ball {
 public:
  Black(Real x, Real y);
  ~Black();
  void die(int);
  void tick(Real);
  void draw();

  Real acceleration, horizon;
  int likesPlayer; /* 1: attracted by ply. 0: unaffected. -1: repelled */
};

#endif
